% Toolbox for global optimization of linear pencil beams with constrained dynamic range ratio of excitation coefficients
% Version 1.0 22-02-2022
% Requirements
%    Matlab R2019 or newer
%    Mosek 8 or newer
%
% This toolbox implements design methods desribed in paper
%    M. Matijascic, M. Jurisic Bellotti, M. Vucic, G. Molnar,
%    Optimum Synthesis of Pencil Beams with Constrained Dynamic Range Ratio
%    International Journal of Antennas and Propagation, 2022
%
% Design of linear pencil beams
%    pb_global   - Global design of linear pencil beam arrays with constrained DRR and arbitrary coefficient signs.
%                  Arrays with minimum SLL and with minimum SLP are supported.
%    pb_positive - Convex design of linear pencil beams with constrained DRR and all positive coefficients.
%                  Arrays with minimum SLL and with minimum SLP are supported.
%    pb_mindrr   - Design for pencil beam array with minimum DRR and specified beam efficiency.
%
% Auxiliary functions
%    pbsolver    - Solver implementing branch and bound search from Section 2.3
%    pb14        - Optimization problem in (14)
%    pb15        - Optimization problem in (15)
%    pb22        - Optimization problem in (22)
%    pb23        - Optimization problem in (23)
%    pb_be       - Beam efficiency calculation
%
% Design examples
%    pb_examples - Function calls for several examples provided in the paper
%


