% pb15 - Part of solver for minimization of SLL - testing branches leaving a node
%
% Reference:
%    M. Matijascic, M. Jurisic Bellotti, M. Vucic, G. Molnar,
%    Optimum Synthesis of Pencil Beams with Constrained Dynamic Range Ratio
%    International Journal of Antennas and Propagation, 2022
%    Section 2, Expression (15)
%

function [a,d,suc]=pb15(x,S,K,D,uq)

% variables: [a,d,t,aux]

Q=length(uq);
N=length(x);

P.c=[zeros(1,N),1,zeros(1,1+3*Q)];

a1=[ones(1,N),zeros(1,2+3*Q)];
m=diag(1-2*S(1:K)); 
a2=[ m,zeros(K,N-K+1),D*ones(K,1),zeros(K,3*Q);...
    -m,zeros(K,N-K+1), -ones(K,1),zeros(K,3*Q);...
     zeros(N-K,K), eye(N-K),zeros(N-K,1),D*ones(N-K,1),zeros(N-K,3*Q);...
     zeros(N-K,K),-eye(N-K),zeros(N-K,1),D*ones(N-K,1),zeros(N-K,3*Q)];
ze=[zeros(Q,N),ones(Q,1),zeros(Q,1)];
co=[cos(uq'*x'),zeros(Q,2)];
si=[sin(uq'*x'),zeros(Q,2)];
g=reshape([ze(:),co(:),si(:)]',3*Q,N+2);
a3=[g,-eye(3*Q)];
P.a=[a1;a2;a3];

P.blc=[1,zeros(1,2*N+3*Q)];
P.buc=[1,Inf*ones(1,2*N),zeros(1,3*Q)];
P.blx=[-Inf*ones(1,N+1),0,-Inf*ones(1,3*Q)];
P.bux=Inf*ones(1,N+2+3*Q);

[~,res]=mosekopt('symbcon echo(0)');
P.cones.type=res.symbcon.MSK_CT_QUAD*ones(1,Q);
P.cones.sub=N+3:N+2+3*Q;
P.cones.subptr=1:3:3*Q;

[~,res]=mosekopt('minimize echo(0)',P);

a=res.sol.itr.xx(1:N);
d=res.sol.itr.xx(N+1);
suc=strcmp(res.sol.itr.solsta,'OPTIMAL') && strcmp(res.rcodestr,'MSK_RES_OK');

