% pb22 - Part of solver for minimization of SLP - node testing
%
% Reference:
%    M. Matijascic, M. Jurisic Bellotti, M. Vucic, G. Molnar,
%    Optimum Synthesis of Pencil Beams with Constrained Dynamic Range Ratio
%    International Journal of Antennas and Propagation, 2022
%    Section 2, Expression (22)
%

function [a,d,suc]=pb22(x,S,D,uq,mu)

% variables: [a,d,t,aux]

Q=length(uq);
N=length(x);

P.c=[zeros(1,N),1,0,zeros(1,2*Q+1)];

a1=[ones(1,N),0,0,zeros(1,2*Q+1)];
m=diag(1-2*S); 
a2=[ m,zeros(N,1),D*ones(N,1),zeros(N,2*Q+1);...
    -m,zeros(N,1), -ones(N,1),zeros(N,2*Q+1)];
simps_coeffs=[1,repmat([2, sqrt(2)], 1,(Q-3)/2),2,1]';
ze=[zeros(1,N),mu,0];

co=simps_coeffs.*[cos(uq'*x'),zeros(Q,2)];
si=simps_coeffs.*[sin(uq'*x'),zeros(Q,2)];
g=[ze;co;si];
a3=[g,-eye(2*Q+1)];
P.a=[a1;a2;a3];

P.blc=[1,zeros(1,(2*N)+2*Q+1)];
P.buc=[1,Inf*ones(1,2*N),zeros(1,2*Q+1)];
P.blx=[-Inf*ones(1,(N+1)),0,-Inf*ones(1,(2*Q+1))];
P.bux=Inf*ones(1,(N+2)+(2*Q+1)); %update

[~,res]=mosekopt('symbcon echo(0)');
P.cones.type=res.symbcon.MSK_CT_QUAD;
P.cones.sub=N+3:(N+2)+2*Q+1;
P.cones.subptr=1;

[~,res]=mosekopt('minimize echo(0)',P);

a=res.sol.itr.xx(1:N);
d=res.sol.itr.xx(N+1);
suc=strcmp(res.sol.itr.solsta,'OPTIMAL') && strcmp(res.rcodestr,'MSK_RES_OK');




