% pb_be - Beam efficiency calculation
%
% Reference:
%    M. Matijascic, M. Jurisic Bellotti, M. Vucic, G. Molnar,
%    Optimum Synthesis of Pencil Beams with Constrained Dynamic Range Ratio
%    International Journal of Antennas and Propagation, 2022
%

function BE=pb_be(x,a,lambda,BW)

N=length(x);
Q=10*N+1;

theta_s=BW/2;   
w_s=sin(theta_s);

% Calculate sidelobe power using Simpsons formula
w=linspace(w_s,1,Q);                              % sidelobe region in w domain
a=a(:)'; x=x(:); f_w=a*exp(1j*(2*pi/lambda*x*w)); % radiation pattern values in discrete points w
Kq=[1,repmat([2, sqrt(2)], 1,(Q-3)/2),2,1];                   % expression (19)
SidelobePower=4*pi*(1-w_s)/(3*(Q-1))*sum(Kq.^2.*abs(f_w).^2); % expression (18)

% Calculate total power
TotalPower=4*pi*sum(a.^2);

BE=1-SidelobePower/TotalPower;

