% pb_examples - Examples of pencil beam design.
%
% Provides function calls for examples in the paper:
%    M. Matijascic, M. Jurisic Bellotti, M. Vucic, G. Molnar,
%    Optimum Synthesis of Pencil Beams with Constrained Dynamic Range Ratio
%    International Journal of Antennas and Propagation, 2022
%
% Examples from the paper
%
%    Figure 2 - beam width of 10 degrees
%    % [a_opt, d_opt] = pb_global(         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global(0.5*(0:29),   2,      1, 10*pi/180, 300,      'SLL');
%
%    Figure 3 - beam width of 10 degrees
%    % [a_opt, d_opt] = pb_global(         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global(0.5*(0:29), 2.5,      1, 10*pi/180, 301,      'SLP');
%
%    Table 4
%    % [a_opt, d_opt] = pb_global(         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global(0.5*(0:15), 1.8,      1, 10*pi/180, 160,      'SLL');
%
%    Table 5
%    % [a_opt, d_opt] = pb_global(         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global(0.5*(0:29), 2.4,      1,  6*pi/180, 300,      'SLL');
%
%    Table 8
%    % [a_opt, d_opt] = pb_global(         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global(0.5*(0:15),   2,      1, 20*pi/180, 161,      'SLP');
%
%    Table 9
%    % [a_opt, d_opt] = pb_global(         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global(0.5*(0:29), 2.5,      1, 12*pi/180, 301,      'SLP');
%
%    Table 10
%      x2 = [0.2521 0.7211 1.2293 1.7101 2.2323 2.7372 3.2884 3.8336 4.4378 5.0599 5.7283 6.5267 7.3945 8.2814 9.1635 9.9755];
%      x  = [-x2(end:-1:1), x2];
%    % [a_opt, d_opt] = pb_global(x, D, lambda,       BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global(x, 2,      1, 6*pi/180, 321,      'SLP');
%
%    Table 11
%    % [a_opt,drr_opt,be_opt]=pb_mindrr( N,        BW, be_des, e_tol);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(15, 25*pi/180, 0.9990,  1e-3);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(15, 25*pi/180, 0.9950,  1e-3);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(15, 25*pi/180, 0.9900,  1e-3);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(30, 12*pi/180, 0.9990,  1e-3);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(30, 12*pi/180, 0.9950,  1e-3);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(30, 12*pi/180, 0.9900,  1e-3);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(40,  9*pi/180, 0.9990,  1e-3);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(40,  9*pi/180, 0.9950,  1e-3);
%      [a_opt,drr_opt,be_opt]=pb_mindrr(40,  9*pi/180, 0.9900,  1e-3);
%
% Examples of solver calls for
%    - global optimization with arbitrary coefficients (all coefficient signs allowed)
%    - convex optimization with positive-only coefficients
%
%    Minimum SLL
%    % [a_opt, d_opt] = pb_global  (         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global  (0.5*(0:15), 1.8,      1, 10*pi/180, 160,      'SLL'); % arbitrary coefficients
%    % [a_opt, d_opt] = pb_positive(         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_positive(0.5*(0:15), 1.8,      1, 10*pi/180, 160,      'SLL'); % positive-only coefficients
%
%    Minimum SLP
%    % [a_opt, d_opt] = pb_global  (         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_global  (0.5*(0:15),   2,      1, 20*pi/180, 161,      'SLP'); % arbitrary coefficients
%    % [a_opt, d_opt] = pb_positive(         x,   D, lambda,        BW,   Q, DesignType);
%      [a_opt, d_opt] = pb_positive(0.5*(0:15),   2,      1, 20*pi/180, 161,      'SLP'); % positive-only coefficients
%


