% pbsolver - Solver implementing branch and bound search from Section 2.3
%
% Reference:
%    M. Matijascic, M. Jurisic Bellotti, M. Vucic, G. Molnar,
%    Optimum Synthesis of Pencil Beams with Constrained Dynamic Range Ratio
%    International Journal of Antennas and Propagation, 2022
%    Section 2
%
% Note:
%    1. This solver utilizes recursion.
%

function [a_opt,d_opt]=pbsolver(x,D,uq,mu,p,a_opt,d_opt,S,DesignType)

N=length(x);

B =sum(double(fliplr(~S)).*2.^(N-1:-1:0));
Br=sum(double(      (~S)).*2.^(N-1:-1:0));

if B<=Br
   if strcmp(DesignType,'SLL')
      [aa,dd,suc]=pb14(x,S,D,uq);
   elseif strcmp(DesignType,'SLP')
      [aa,dd,suc]=pb22(x,S,D,uq,mu);
   else
      error('Illegal DesignType.')
   end
   if (dd < d_opt) && suc
      a_opt=aa;
      d_opt=dd;
   end
end

p=p+1;
for s=p:N
   S1=S;
   S1(s)=0;

   if s<N
      if strcmp(DesignType,'SLL')
         [~,dd,suc]=pb15(x,S1,s,D,uq);
      elseif strcmp(DesignType,'SLP')
         [~,dd,suc]=pb23(x,S1,s,D,uq,mu);
      else
         error('Illegal DesignType.')
      end

      if (dd>d_opt) && suc
         continue;
      end
   end

   [a_opt,d_opt]=pbsolver(x,D,uq,mu,s,a_opt,d_opt,S1,DesignType);
end


